@@ -1,14 +1,14 @@
 package IM::Engine::Plugin::Dispatcher::AugmentsDispatcher;
 use Moose::Role;
-with 'IM::Engine::Plugin::Dispatcher::RequiresDispatcherPlugin';
+with 'IM::Engine::RequiresPlugins' => {
+    plugins => 'IM::Engine::Plugin::Dispatcher',
+};
 
 requires 'new_rules';
 
 sub augment_dispatcher {
-    my $self = shift;
-    my $args = shift;
-
-    my $dispatcher = $args->{dispatcher};
+    my $self       = shift;
+    my $dispatcher = shift;
 
     for my $rule ($self->new_rules) {
         $dispatcher->add_rule($rule);
