@@ -1,6 +1,8 @@
 package IM::Engine::Plugin::Dispatcher::ShortcutsDispatch;
 use Moose::Role;
-with 'IM::Engine::Plugin::Dispatcher::RequiresDispatcherPlugin';
+with 'IM::Engine::RequiresPlugins' => {
+    plugins => 'IM::Engine::Plugin::Dispatcher',
+};
 
 requires 'shortcut_dispatch';
 
